@@ -31,18 +31,18 @@ documentRoot($htpath);
 Style('Crystal');
 size($size);
 clasic(1) if(defined param('clasic'));
-my $zoom = div({style=>"font-size:$size"."px;"},
-a({-href=>'./crystal.pl?style=Crystal&amp;size=16',-class => "treeviewLink$size"},'16').'&#160;|&#160;'.
-a({-href=>'./crystal.pl?style=Crystal&amp;size=22',-class => "treeviewLink$size"},'22').'&#160;|&#160;'.
-a({-href=>'./crystal.pl?style=Crystal&amp;size=32',-class => "treeviewLink$size"},'32').'&#160;|&#160;'.
-a({-href=>'./crystal.pl?style=Crystal&amp;size=48',-class => "treeviewLink$size"},'48').'&#160;|&#160;'.
-a({-href=>'./crystal.pl?style=Crystal&amp;size=64',-class => "treeviewLink$size"},'64').'&#160;|&#160;'.
-a({-href=>'./crystal.pl?style=Crystal&amp;size=64',-class => "treeviewLink$size"},'128'));
-print header(),
-start_html(
-	-title => 'Crystal',
-	-script => jscript() . preload(),
-	-style => {-code => css()}
-),
-div({align => 'center'},$zoom.br().Tree(\@tree)),
-end_html;
\ No newline at end of file
+my $zoom = div(
+               {style => "font-size:$size" . "px;"},
+               a({-href => './crystal.pl?style=Crystal&amp;size=16', -class => "treeviewLink$size"}, '16')
+                 . '&#160;|&#160;'
+                 . a({-href => './crystal.pl?style=Crystal&amp;size=22', -class => "treeviewLink$size"}, '22')
+                 . '&#160;|&#160;'
+                 . a({-href => './crystal.pl?style=Crystal&amp;size=32', -class => "treeviewLink$size"}, '32')
+                 . '&#160;|&#160;'
+                 . a({-href => './crystal.pl?style=Crystal&amp;size=48', -class => "treeviewLink$size"}, '48')
+                 . '&#160;|&#160;'
+                 . a({-href => './crystal.pl?style=Crystal&amp;size=64', -class => "treeviewLink$size"}, '64')
+                 . '&#160;|&#160;'
+                 . a({-href => './crystal.pl?style=Crystal&amp;size=64', -class => "treeviewLink$size"}, '128')
+);
+print header(), start_html(-title => 'Crystal', -script => jscript() . preload(), -style => {-code => css()}), div({align => 'center'}, $zoom . br() . Tree(\@tree)), end_html;
